@@ -181,6 +181,11 @@ bool MuonMainWindow::isConnected() {
     return connected;
 }
 
+QSize MuonMainWindow::sizeHint() const
+{
+    return KXmlGuiWindow::sizeHint().expandedTo(QSize(900, 500));
+}
+
 void MuonMainWindow::checkForUpdates()
 {
 }
@@ -189,6 +194,7 @@ void MuonMainWindow::workerEvent(QApt::WorkerEvent event)
 {
     switch (event) {
     case QApt::CacheUpdateStarted:
+        break;
     case QApt::PackageDownloadStarted:
         m_powerInhibitor = Solid::PowerManagement::beginSuppressingSleep(i18nc("@info:status", "Muon is making system changes"));
     case QApt::CommitChangesStarted:
@@ -235,6 +241,7 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
                      "any packages.");
         title = i18nc("@title:window", "Unable to obtain package system lock");
         KMessageBox::error(this, text, title);
+        setActionsEnabled();
         break;
     case QApt::DiskSpaceError: {
         QString drive = args["DirectoryString"].toString();
@@ -243,6 +250,8 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
                      "at %1 to continue with this operation.", drive);
         title = i18nc("@title:window", "Low disk space");
         KMessageBox::error(this, text, title);
+        setActionsEnabled();
+        break;
     }
     case QApt::FetchError:
         text = i18nc("@label",
@@ -252,7 +261,7 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
         break;
     case QApt::CommitError: {
         m_errorStack.append(args);
-        break;
+        return;
     }
     case QApt::AuthError:
         text = i18nc("@label",
@@ -284,6 +293,7 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
         }
         title = i18nc("@title:window", "Untrusted Packages");
         KMessageBox::errorList(this, text, untrustedItems, title);
+        setActionsEnabled();
         break;
     }
     case QApt::UserCancelError:
@@ -292,7 +302,6 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
         break;
     }
 
-    setActionsEnabled();
     m_canExit = true; // If we were committing changes, we aren't anymore
 }
 
@@ -321,6 +330,31 @@ void MuonMainWindow::questionOccurred(QApt::WorkerQuestion code, const QVariantM
     QVariantMap response;
 
     switch (code) {
+    case QApt::ConfFilePrompt: {
+        // TODO: diff support
+        QString oldFile = args["OldConfFile"].toString();
+
+        QString title = i18nc("@title:window", "Configuration File Changed");
+        QString text = i18nc("@label Notifies a config file change",
+                             "A new version of the configuration file "
+                             "<filename>%1</filename> is available, but your version has "
+                             "been modified. Would you like to keep your current version "
+                             "or install the new version?", oldFile);
+
+        KGuiItem useNew(i18nc("@action Use the new config file", "Use New Version"));
+        KGuiItem useOld(i18nc("@action Keep the old config file", "Keep Old Version"));
+
+        int ret = KMessageBox::questionYesNo(this, text, title, useNew, useOld);
+
+        if (ret == KMessageBox::Yes) {
+            response["ReplaceFile"] = true;
+        } else {
+            response["ReplaceFile"] = false;
+        }
+
+        m_backend->answerWorkerQuestion(response);
+        break;
+    }
     case QApt::MediaChange: {
         QString media = args["Media"].toString();
         QString drive = args["Drive"].toString();
@@ -399,6 +433,7 @@ void MuonMainWindow::showQueuedErrors()
 
     QString title = i18nc("@title:window", "Commit error");
     KMessageBox::detailedError(this, text, details, title);
+    m_canExit = true;
 }
 
 void MuonMainWindow::reload()
