@@ -293,6 +293,7 @@ void MainWindow::errorOccurred(QApt::ErrorCode error, const QVariantMap &details
         if (m_downloadWidget) {
             m_downloadWidget->clear();
         }
+    case QApt::AuthError:
         m_managerWidget->setEnabled(true);
         QApplication::restoreOverrideCursor();
         returnFromPreview();
@@ -316,7 +317,10 @@ void MainWindow::workerEvent(QApt::WorkerEvent event)
         break;
     case QApt::CacheUpdateFinished:
     case QApt::CommitChangesFinished:
-        reload();
+        if (m_backend) {
+            reload();
+            setActionsEnabled();
+        }
     case QApt::PackageDownloadFinished:
         returnFromPreview();
         if (m_warningStack.size() > 0) {
@@ -391,8 +395,6 @@ void MainWindow::returnFromPreview()
     m_previewAction->setText(i18nc("@action", "Preview Changes"));
     disconnect(m_previewAction, SIGNAL(triggered()), this, SLOT(returnFromPreview()));
     connect(m_previewAction, SIGNAL(triggered()), this, SLOT(previewChanges()));
-    // We may not have anything to preview; check.
-    setActionsEnabled();
 }
 
 void MainWindow::startCommit()
